# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsMonthlyResponse(Model):
    """PlaceDigestSavingsMonthlyResponse.

    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_id: The place identifier
    :type place_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param global_use_unit: The use unit of measure
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit: The bodyline's cost unit of measure for this
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of SavingsMonthly data per commodity
    :type commodities:
     list[~energycap.sdk.models.PlaceDigestSavingsMonthlyResponseCommodityData]
    :param results: An array of SavingsMonthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestSavingsMonthlyResponseResults]
    """

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[PlaceDigestSavingsMonthlyResponseCommodityData]'},
        'results': {'key': 'results', 'type': '[PlaceDigestSavingsMonthlyResponseResults]'},
    }

    def __init__(self, place_code=None, place_info=None, place_id=None, updated=None, global_use_unit=None, cost_unit=None, commodities=None, results=None):
        super(PlaceDigestSavingsMonthlyResponse, self).__init__()
        self.place_code = place_code
        self.place_info = place_info
        self.place_id = place_id
        self.updated = updated
        self.global_use_unit = global_use_unit
        self.cost_unit = cost_unit
        self.commodities = commodities
        self.results = results
